package cv04.pv239.muni.cz.cv04;

import com.google.android.gms.common.ConnectionResult;
import com.google.android.gms.common.api.GoogleApiClient;
import com.google.android.gms.location.LocationServices;

import android.Manifest;
import android.content.SharedPreferences;
import android.content.pm.PackageManager;
import android.location.Location;
import android.os.Bundle;
import android.support.v4.app.ActivityCompat;
import android.support.v7.app.AppCompatActivity;
import android.text.TextUtils;
import android.util.Log;

import java.util.List;

import cv04.pv239.muni.cz.cv04.database.MyLocation;

public class MainActivity extends AppCompatActivity implements
        GoogleApiClient.ConnectionCallbacks, GoogleApiClient.OnConnectionFailedListener {

    public static final int MY_PERMISSIONS_REQUEST_LOCATION = 12;
    public static final String MY_LOCATION = "my_location";
    public static final String MY_SHARED_PREFS = "mySharedPrefs";
    private GoogleApiClient mGoogleApiClient;
    private Location mLastLocation;

    private SharedPreferences mSharedPreferences;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        // init shared preferences
        mSharedPreferences = getSharedPreferences(MY_SHARED_PREFS, MODE_PRIVATE);

        // print number of locations saved in DB to the Log
        List<MyLocation> myLocationList = MyLocation.listAll(MyLocation.class);
        if (myLocationList != null && myLocationList.size() > 0) {
            Log.d("Locations in DB: ", String.valueOf(myLocationList.size()));
        }

        // print last saved location saved in Shared preferences to the Log
        if (mSharedPreferences.contains(MY_LOCATION)) {
            String location = mSharedPreferences.getString(MY_LOCATION, "");
            if (!TextUtils.isEmpty(location)) {
                Log.d("pref_location", location);

            }
        }

        // Create an instance of GoogleAPIClient (to get location from)
        if (mGoogleApiClient == null) {
            mGoogleApiClient = new GoogleApiClient.Builder(this)
                    .addConnectionCallbacks(this)
                    .addOnConnectionFailedListener(this)
                    .addApi(LocationServices.API)
                    .build();
        }
    }

    @SuppressWarnings("ResourceType")
    private void getLocation() {
        // googleApiClient is connected and permission is granted so get the last known location
        mLastLocation = LocationServices.FusedLocationApi.getLastLocation(
                mGoogleApiClient);
        Log.d("location", String.valueOf(mLastLocation.getLongitude()));
        // save the last known location to Shared preferences
        mSharedPreferences.edit().putString(MY_LOCATION, String.valueOf(mLastLocation.getLongitude())).apply();
        // save the last location to DB
        MyLocation myLocation = new MyLocation();
        myLocation.lati = mLastLocation.getLatitude();
        myLocation.longi = mLastLocation.getLongitude();
        myLocation.save();
    }

    protected void onStart() {
        mGoogleApiClient.connect();
        super.onStart();
    }

    protected void onStop() {
        mGoogleApiClient.disconnect();
        super.onStop();
    }

    @Override
    public void onConnected(Bundle bundle) {
        if (ActivityCompat.checkSelfPermission(this, Manifest.permission.ACCESS_COARSE_LOCATION) != PackageManager.PERMISSION_GRANTED) {
            // if permission is not enabled on API 23 and above ask user to grant this permission
            ActivityCompat.requestPermissions(this,
                    new String[]{Manifest.permission.ACCESS_COARSE_LOCATION},
                    MY_PERMISSIONS_REQUEST_LOCATION);
            return;
        }
        getLocation();
    }

    @Override
    public void onConnectionSuspended(int i) {

    }

    @Override
    public void onConnectionFailed(ConnectionResult connectionResult) {

    }

    @SuppressWarnings("ResourceType")
    @Override
    public void onRequestPermissionsResult(int requestCode, String[] permissions, int[] grantResults) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults);
        if (requestCode == MY_PERMISSIONS_REQUEST_LOCATION) {
            if (grantResults.length > 0
                    && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                // if permission has been granted
                getLocation();
            }
        }
    }
}